from sklearn.preprocessing import StandardScaler, LabelEncoder

class PyBandiger:
    def __init__(self):
        self.le = {}
        self.ss = StandardScaler()

    def clean(self, data):
        cat_col = data.select_dtypes(include='object').columns
        num_col = data.select_dtypes(include=['int', 'float']).columns
        for col in cat_col:
            data[col] = data[col].fillna('Missing')
        for col in num_col:
            data[col] = data[col].fillna(data[col].mean())
        return data

    def EncodeAndScale_fit(self, data):
        cat_col = data.select_dtypes(include='object').columns
        num_col = data.select_dtypes(include=['int', 'float']).columns
        for col in cat_col:
            encoder = LabelEncoder()
            self.le[col] = encoder.fit_transform(data[col])
        data[num_col] = self.ss.fit_transform(data[num_col])
        return data

    def EncodeAndScale_transform(self, data):
        cat_col = data.select_dtypes(include='object').columns
        num_col = data.select_dtypes(include=['int', 'float']).columns
        for col in cat_col:
            data[col] = self.le[col].transform(data[col])
        data[num_col] = self.ss.transform(data[num_col])
        return data


from setuptools import setup, find_packages

setup(
    name='pybandiger',
    version='0.1.5',
    packages=find_packages(),
    install_requires=[
        'scikit-learn',
        'pandas',
    ],
    author='Lansari Fedi',
    author_email='lansarifedi7@gmail.com',
    description='A data wrangling library',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/LansariFedi/PyBandiger',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
)